<?php
/**
 * DokuWiki Default Template
 *
 * This is the template you need to change for the overall look
 * of DokuWiki.
 *
 * You should leave the doctype at the very top - It should
 * always be the very first line of a document.
 *
 * @link   http://wiki.splitbrain.org/wiki:tpl:templates
 * @author Andreas Gohr <andi@splitbrain.org>
 */

// must be run from within DokuWiki
if (!defined('DOKU_INC')) die();

// verify if the given action is enabled
function is_action_enabled($type) {
        $ctype = $type;
        if($type == 'history') $ctype='revisions';
        return actionOK($ctype);
}

// changes the display style of the given action group, depending on the config file
function action_group_status($groupname) {
        if (tpl_getConf('btl_default_' . $groupname . '_actions_status') == "closed") {
                echo " style='display:none;'" ;
        }
}

// include functions that provide sidebar functionality
@require_once(dirname(__FILE__).'/tplfn_sidebar.php');

// include translations of the template strings
@require_once(dirname(__FILE__).'/lang/'.tpl_getConf('btl_language').'/settings.php');

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $conf['lang']?>"
 lang="<?php echo $conf['lang']?>" dir="<?php echo $lang['direction']?>">
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <title>
    <?php tpl_pagetitle()?>
    [<?php echo strip_tags($conf['title'])?>]
  </title>

  <?php tpl_metaheaders()?>
  <?php /*old includehook*/ @include('meta.php')?>

  <?php
    $WIKICSS = 'wiki.css';
    if ( file_exists(DOKU_INC.DOKU_TPL.$WIKICSS) ) $CSS = DOKU_TPL.$WIKICSS;
    else $CSS = '/common/css/'.$WIKICSS;
  ?>
    <link rel="stylesheet"           media="all"    type="text/css" title="default"  href="<?php echo $CSS ?>" />
    <link rel="stylesheet"           media="print"  type="text/css" title="print"  href="/common/css/wiki_print.css" />

</head>

<body>

<?php @include('../common/php_inc/bandeau.php');?>

    <div id="WikiBreadCrumbs">
    <?php html_msgarea()?>

    <?php if($conf['breadcrumbs']){
      tpl_breadcrumbs();
      //tpl_youarehere() //(some people prefer this)
    }

    if($conf['youarehere']){
      tpl_youarehere();
    } ?>
    </div> <!-- Fin de #WikiBreadCrumbs -->

  <?php flush()?>

  <div id="SideBar">

    <div id="WikiActionLink1" class="BlockBase SideBarElement ActionLink">
      <div class="TitleBlockBase"><?php echo $lang['btl_strip_page_actions']; ?></div>
      <?php if (is_action_enabled('history')) { ?>
        <div class="ActionLink"><?php tpl_actionlink('history')?></div>
      <?php } ?>
      <?php if (is_action_enabled('backlink')) { ?>
        <div class="ActionLink"><?php tpl_actionlink('backlink')?></div>
      <?php } ?>
      <?php if (is_action_enabled('edit')) { ?>
        <div class="ActionLink"><?php tpl_actionlink('edit')?></div>
      <?php } ?>
    </div> <!-- Fin de #WikiActionLink1 -->

    <div id="WikiActionLink2" class="BlockBase SideBarElement ActionLink">
      <div class="TitleBlockBase"><?php echo $lang['btl_strip_wiki_actions']; ?></div>
      <?php if (is_action_enabled('index')) { ?>
        <div class="ActionLink"><?php tpl_actionlink('index')?></div>
      <?php } ?>
      <?php if (is_action_enabled('recent')) { ?>
        <div class="ActionLink"><?php tpl_actionlink('recent')?></div>
      <?php } ?>
      <?php if (is_action_enabled('admin') && $INFO['perm'] == 255) { ?>
        <div class="ActionLink"><?php tpl_actionlink('admin') ?></div>
      <?php } ?>
    </div> <!-- Fin de #WikiActionLink2 -->

    <div id="WikiActionLink3" class="BlockBase SideBarElement ActionLink">
      <div class="TitleBlockBase"><?php echo $lang['btl_strip_user_actions']; ?></div>
      <?php if (is_action_enabled('login')) { ?>
        <div class="ActionLink"><?php tpl_actionlink('login')?>
        <?php
//          if ($_SERVER['REMOTE_USER']){
//          echo $INFO['userinfo']['name'] ;
//          }
        ?>
        </div>
      <?php } ?>
      <?php if (is_action_enabled('profile') && $_SERVER['REMOTE_USER']) { ?>
        <div class="ActionLink"><?php tpl_actionlink('profile') ?></div>
      <?php } ?>
      <?php if (is_action_enabled('subscribe')) { ?>
        <?php if($conf['useacl'] && $ACT == 'show' && $conf['subscribers'] == 1 && $_SERVER['REMOTE_USER']){ ?>
          <div class="ActionLink"><?php tpl_actionlink('subscribe')?></div>
        <?php } ?>
      <?php } ?>
      <div id="WikiInfoUser">
        <?php tpl_userinfo();
              echo "\n"; ?>
      </div> <!-- Fin de #WikiInfoUser -->
    </div> <!-- Fin de #WikiActionLink3 -->

    <div id="WikiIndex" class="BlockBase SideBarElement">
      <?php tpl_sidebar();
       echo "\n"; ?>
    </div> <!-- Fin de #WikiIndex -->

    <div id="CloudTags" class="BlockBase SideBarElement">
      <div class="TitleBlockBase"><?php echo $lang['btl_strip_tags']; ?></div>
    <?php
      $nb_tags = $conf['tpl']['Union']['btl_tags_number'];
      $rcopy = p_render('xhtml', p_get_instructions('~~TAGCLOUD:'.$nb_tags.'~~ [[wiki:tag:nuage|-'.$lang['btl_tags_text'].'-]]'), $info);
      $rcopy = trim(ereg_replace('<p>|</p>|'."\n\n", '', $rcopy));
      echo $rcopy."\n";
    ?>
    </div> <!-- Fin de #CloudTags -->

    <?php  if (is_action_enabled('search')) { ?>
      <div id="SiteSearch" class="BlockBase SideBarElement">
        <div class="TitleBlockBase"><?php echo $lang['btl_strip_search']; ?></div>
        <div class="centeralign"><?php tpl_searchform()?></div>
      </div> <!-- Fin de #WikiSearch -->
    <?php } ?>

    <div id="Feeds" class="BlockBase SideBarElement">
      <ul>
        <li><a title="Souscrire au fil RSS des récénts changements du Wiki" href="<?php echo DOKU_BASE; ?>feed.php">
          <span class="TextOnly">Souscrire au fil RSS &laquo;&nbsp;</span>les récénts changements du Wiki<span class="TextOnly">&nbsp;&raquo;</span></a>

        </li>
      </ul>
    </div> <!-- Fin de #Feeds -->

  </div> <!-- Fin de #sidebar -->

  <div id="Main" class="BlockBase">

    <div id="WikiContent">
      <?php tpl_content()?>
    </div> <!-- Fin de #WikiContent -->

<!--    <div class="Spacer"></div> -->

    <div id="WikiInfoPage">
      <?php tpl_pageinfo()?>
    </div> <!-- Fin de #WikiInfoPage -->
    <?php flush()?>

  </div> <!-- fin de #Main -->

  <?php @include('../common/php_inc/footer.php')?>
  <div class="no"><?php /* provide DokuWiki housekeeping, required in all templates */ tpl_indexerWebBug()?></div>

</body>
</html>
