/**
 * Javascript for the new index view
 *
 * Based on work for DokuWiki by :
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Ben Coburn <btcoburn@silicodon.net>
 */

Yani = {

     /**
     * Delay in ms before showing the throbber.
     * Used to skip the throbber for fast AJAX calls.
     */
    throbber_delay: 500,

    /**
     * Attach event handlers to all "folders" below the given element
     */
    treeattach: function(obj){
        if(!obj) return;

        // apply IdxScroll class on specific UL
	var nblines = 0;
        var items = getElementsByClass('level[3456789]+',obj,'li');
        for(var i=0; i<items.length; i++){
            var elem = items[i];

	    // Look for the link into the li element
            var childs = elem.childNodes;
            while (childs[0].tagName != 'A') {
              childs = childs[0].childNodes;
            }
	    // Try to guess the lines' number display by this list
	    // , the li element
	    // We assume that the return comes at 15 characters
	    if ( childs[0].title.length > 15 ) nblines++;
	    nblines++;
	    
            var listitem = elem.parentNode;
            // if ( items.length > 5) listitem.className = 'idx IdxScroll';
            if ( nblines > 14 ) listitem.className = 'idx IdxScroll';
        }

        // execute Yani.toggle when click on a yani class' link (a)
        var items = getElementsByClass('yani',obj,'a');
        for(var i=0; i<items.length; i++){
            var elem = items[i];
            elem.className = 'yani closed';
            elem.title = 'Déplier la catégorie';

            // attach action to make the link clickable by AJAX
            addEvent(elem,'click',function(e){ return Yani.toggle(e,this); });

            // get the listitem the elem belongs to
            var listitem = elem.parentNode;
            while (listitem.tagName != 'LI') {
              listitem = listitem.parentNode;
            }
            //when there are uls under this listitem mark this listitem as opened
            if (listitem.getElementsByTagName('ul').length) {
              listitem.open = true;
              elem.className = 'yani open';
              elem.title = 'Replier la catégorie';
            }
        }
    },

    /**
     * Open or close a subtree using AJAX
     * The contents of subtrees are "cached" untill the page is reloaded.
     * A "loading" indicator is shown only when the AJAX call is slow.
     */
    toggle: function(e,clicky){
        var listitem = clicky.parentNode.parentNode;

        listitem.open = !listitem.open;
        // listitem.open represents now the action to be done

        // if already open, close by removing the sublist
        var sublists = listitem.getElementsByTagName('ul');
        if(!listitem.open){
            if (sublists.length) {
              sublists[0].style.display='none';
            }
            listitem.className='closed';
            clicky.className = 'yani closed';
            clicky.title = 'Déplier la catégorie';
            e.preventDefault();
            return false;
        }

        // just show if already loaded
        if(sublists.length && listitem.open){
            sublists[0].style.display='';
            listitem.className='open';
            clicky.className = 'yani open';
            clicky.title = 'Replier la catégorie';
            e.preventDefault();
            return false;
        }

        // prepare an AJAX call to fetch the subtree
        var ajax = new sack(DOKU_TPL + '/yani_ajax.php');
        ajax.AjaxFailedAlert = '';
        ajax.encodeURIString = false;
        if(ajax.failed) return true;

        //prepare the new ul
        var ul = document.createElement('ul');
        ul.className = 'idx';
        timeout = window.setTimeout(function(){
            // show the throbber as needed
            if (listitem.open) {
              ul.innerHTML = '<li><img src="'+DOKU_BASE+'lib/images/throbber.gif" alt="loading..." title="loading..." /></li>';
              listitem.appendChild(ul);
              listitem.className='open';
            }
        }, this.throbber_delay);
        ajax.elementObj = ul;
        ajax.afterCompletion = function(){
            window.clearTimeout(timeout);
            Yani.treeattach(ul);
            if (listitem.className!='open') {
              if (!listitem.open) {
                ul.style.display='none';
              }
              listitem.appendChild(ul);
              if (listitem.open) {
                listitem.className='open';
                clicky.className = 'yani open';
                clicky.title = 'Replier la catégorie';
              }
            }
        };
        ajax.runAJAX(clicky.search.substr(1)+'&call=index');
        e.preventDefault();
        return false;
    }
};


addInitEvent(function(){
    Yani.treeattach($('index__tree'));
});

